@@ -1,7 +1,7 @@
 ﻿// samplv1.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1795,7 +1795,7 @@ void samplv1_impl::process_midi ( uint8_t *data, uint32_t size )
 					m_dca1.env.note_off(&pv->dca1_env);
 					m_dcf1.env.note_off(&pv->dcf1_env);
 					m_lfo1.env.note_off(&pv->lfo1_env);
-					pv->gen1.setLoop(false);
+				//	pv->gen1.setLoop(false);
 				}
 				m_notes[pv->note] = nullptr;
 				pv->note = -1;
